@@ -12,6 +12,12 @@
 #include "extern.h"
 #include "g_colorname.h"
 
+typedef struct lib_cached_colornameinfo
+{
+  const Colornameinfo *info;
+  struct lib_cached_colornameinfo *next;
+} Cached_Colornameinfo;
+
 int 
 #ifdef _HAVE_PROTOS
 _g_pencolorname (const char *name)
@@ -115,9 +121,14 @@ _g_bgcolorname (name)
 }
 
 /* _string_to_color() searches a database of known color names, in
-   colorname.h, for a specified string.  Matches are case-insensitive and
-   ignore spaces.  A pointer to the retrieved color name info is returned,
-   via a pointer. */
+   g_colorname.h, for a specified string.  Matches are case-insensitive and
+   ignore spaces.  A pointer to the retrieved color name info is returned
+   via a pointer.
+
+   We maintain a linked list of previously found colors, so we don't need
+   to search through the entire (long) color database.  (It contains 600+
+   color name strings.)  */
+
 bool
 #ifdef _HAVE_PROTOS
 _string_to_color (const char *name, const Colornameinfo **info_p)
@@ -127,10 +138,12 @@ _string_to_color (name, info_p)
      const Colornameinfo **info_p;
 #endif
 {
-  const Colornameinfo *info = _colornames; /* see colorname.h */
-  const char *optr;
-  char *squeezed_name, *nptr;
   bool found = false;
+  char *squeezed_name, *nptr;
+  const Colornameinfo *info, *found_info = NULL;
+  const char *optr;
+  Cached_Colornameinfo *cached_info;
+  static Cached_Colornameinfo *cached_list = NULL;
 
   if (name == NULL)		/* avoid core dumps */
     return false;
@@ -148,21 +161,52 @@ _string_to_color (name, info_p)
     }
   *nptr = '\0';
 
-  /* search table */
-  do
+  /* Search our list of cached, previously used color names, doing string
+     comparison.  If this were only for use by the X11 driver, we'd use
+     XrmPermStringToQuark to get a faster-compared representation. */
+  cached_info = cached_list;
+  while (cached_info)
     {
-      if (strcasecmp (info->name, squeezed_name) == 0)
+      if (strcasecmp (cached_info->info->name, squeezed_name) == 0)
 	{
 	  found = true;
+	  found_info = cached_info->info;
 	  break;
 	}
-      info++;
+      cached_info = cached_info->next;
+    }
+
+  if (!found)
+    /* not previously used, so search master colorname table (this is slower) */
+    {
+      info = _colornames;	/* start at head of list in g_colorname.h */
+      while (info->name)
+	{
+	  if (strcasecmp (info->name, squeezed_name) == 0)
+	    {
+	      found = true;
+	      found_info = info;
+	      break;
+	    }
+	  info++;
+	}
+
+      if (found)
+	/* copy to head of cache list */
+	{
+	  Cached_Colornameinfo *old_cached_list;
+
+	  old_cached_list = cached_list;
+	  cached_list = 
+	    (Cached_Colornameinfo *)_plot_xmalloc (sizeof (Cached_Colornameinfo));
+	  cached_list->next = old_cached_list;
+	  cached_list->info = found_info;
+	}
     }
-  while (info->name);
   
   free (squeezed_name);
   if (found)
-    *info_p = info;
+    *info_p = found_info;
 
   return found;
 }
