@@ -8,14 +8,15 @@
 
 struct param_record
 {
-  const char *parameter;
-  const void *default_value;
-  void *value;  
-  bool is_string;
+  const char * const parameter;
+  const Voidptr default_value;
+  Voidptr value;  
+  const bool is_string;
 };
 
 struct param_record _plot_params[NUM_DEVICE_DRIVER_PARAMETERS] =
 {
+  {"BG_COLOR", NULL, NULL, true}, /* X */
   {"BITMAPSIZE", NULL, NULL, true}, /* X */
   {"DISPLAY", NULL, NULL, true}, /* X, XDrawable */
   {"HPGL_ASSIGN_COLORS", "no", NULL, true}, /* hpgl */
@@ -24,13 +25,14 @@ struct param_record _plot_params[NUM_DEVICE_DRIVER_PARAMETERS] =
   {"HPGL_VERSION", "2", NULL, true},	/* hpgl */
   {"HPGL_XOFFSET", "0 cm", NULL, true}, /* hpgl */
   {"HPGL_YOFFSET", "0 cm", NULL, true}, /* hpgl */
-  				/* all but tek and meta */
-  {"MAX_LINE_LENGTH", MAX_UNFILLED_POLYLINE_LENGTH_STRING, NULL, true},
+  {"MAX_LINE_LENGTH", MAX_UNFILLED_POLYLINE_LENGTH_STRING, NULL, true}, /* all but tek and meta */
   {"META_PORTABLE", "no", NULL, true}, /* raw  */
   {"PAGESIZE", "letter", NULL, true}, /* hpgl, fig, ps */
   {"ROTATE", "no", NULL, true},	/* hpgl, fig, ps */
   {"TERM", "tek", NULL, true},	/* tek only! */
+  {"USE_DOUBLE_BUFFERING", "no", NULL, true}, /* X */
   {"VANISH_ON_DELETE", "no", NULL, true}, /* X */
+  {"XDRAWABLE_COLORMAP", NULL, NULL, false}, /* XDrawable, is a Colormap* */
   {"XDRAWABLE_DISPLAY", NULL, NULL, false}, /* XDrawable, is a Display* */
   {"XDRAWABLE_DRAWABLE1", NULL, NULL, false}, /* XDrawable, is a Drawable* */
   {"XDRAWABLE_DRAWABLE2", NULL, NULL, false}, /* XDrawable, is a Drawable* */
