@@ -17,9 +17,11 @@ _y_openpl (void)
 _y_openpl ()
 #endif
 {
-  const char *length_s;
+  const char *length_s, *bg_color_name_s, *double_buffer_s;
   int screen;			/* screen number */
   Screen *screen_struct;	/* screen structure */
+  Colormap *cmap_ptr;
+  unsigned int width, height;
 
   if (_plotter->open)
     {
@@ -70,13 +72,19 @@ _y_openpl ()
 	else
 	  _plotter->max_unfilled_polyline_length = local_length;
       }
+
+      /* find out how long polylines can get */
       _plotter->hard_polyline_length_limit = 
 	XMaxRequestSize(_plotter->dpy) / 2;
   
       /* determine display's default screen, colormap */
       screen = DefaultScreen (_plotter->dpy);
       screen_struct = ScreenOfDisplay (_plotter->dpy, screen);
-      _plotter->cmap = DefaultColormapOfScreen (screen_struct);
+      cmap_ptr = (Colormap *)_get_plot_param ("XDRAWABLE_COLORMAP");
+      if (cmap_ptr == NULL)
+	_plotter->cmap = DefaultColormapOfScreen (screen_struct);
+      else
+	_plotter->cmap = *cmap_ptr;
   
       /* determine dimensions of drawable(s) */
       {
@@ -84,7 +92,6 @@ _y_openpl ()
 	int x, y;
 	unsigned int width1, height1, width2, height2;
 	unsigned int border_width, depth1, depth2;
-	unsigned int width, height;
 	
 	if (_plotter->drawable1)
 	  XGetGeometry (_plotter->dpy, _plotter->drawable1,
@@ -122,14 +129,30 @@ _y_openpl ()
 	_plotter->jmax = 0;
       }
       
-      /* save background/foreground colors for initial drawing state; store
-	 in default drawing state because there's no real drawing state in
-	 the Plotter yet */
-      _plotter->default_drawstate->x_bgcolor 
-	= WhitePixelOfScreen(screen_struct);
-      _plotter->default_drawstate->x_fgcolor 
-	= BlackPixelOfScreen(screen_struct);
-  
+      if (_plotter->drawable1 || _plotter->drawable2)
+	{
+	  double_buffer_s = (const char *)_get_plot_param ("USE_DOUBLE_BUFFERING");
+	  if (strcmp (double_buffer_s, "yes") == 0)
+	  /* user requested double buffering, so allocate additional pixmap
+	     to serve as graphics buffer */
+	    {
+	      _plotter->double_buffering = true;
+	      _plotter->drawable3
+		= XCreatePixmap(_plotter->dpy, 
+				/* this 2nd arg merely determines the screen */
+				_plotter->drawable1 ? 
+				    _plotter->drawable1 : _plotter->drawable2,
+				(unsigned int)width,
+				(unsigned int)height, 
+				(unsigned int)PlanesOfScreen(screen_struct));
+	      /* erase buffer by filling it with background color */
+	      XFillRectangle (_plotter->dpy, _plotter->drawable3, 
+			      _plotter->drawstate->gc_bg,
+			      /* upper left corner */
+			      0, 0,
+			      (unsigned int)width, (unsigned int)height);
+	    }
+	}
     }
   
   /* flag Plotter as open (and having been opened at least once) */
@@ -137,19 +160,28 @@ _y_openpl ()
   _plotter->opened = true;
   (_plotter->page_number)++;
 
-  /* Create an initial drawing state with default attributes, including the
-     just-computed foreground and background colors, and an X GC.  The
-     drawing state won't be fully ready for drawing graphics, since it
-     won't contain an X font.  To retrieve the initial X font, the user
-     will need to invoke space() after openpl(). */
+  /* Note: we do _not_ reset _plotter->frame_number to zero here, unlike
+     what we do for an X Plotter.  Frames for an X Drawable Plotter are
+     numbered consecutively throughout the lifetime of the Plotter. */
+
+  /* Create an initial drawing state with default attributes, including an
+     X GC.  The drawing state won't be ready for drawing graphics, since it
+     won't contain an X font or a meaningful line width.  To retrieve an X
+     font and set the line width, the user will need to invoke space()
+     after openpl(). */
   _plotter->savestate ();
   
-  /* erase drawable by filling it with the background color, via
+  /* if there's a user-specified background color, set it in drawing state */
+  bg_color_name_s = (const char *)_get_plot_param ("BG_COLOR");
+  if (bg_color_name_s)
+    _plotter->bgcolorname (bg_color_name_s);
+  
+  /* clear the drawable(s) by filling them with the background color, via
      XFillRectangle (the just-created drawing state, with the mentioned
      attributes, is used for this) */
 
-  /* commented out because for an XDrawablePlotter, unlike an XPlotter,
-     this may not be appropriate */
+  /* commented out because for an X DrawablePlotter, unlike an X Plotter,
+     this initial clearing may not be appropriate */
   /* _plotter->erase (); */
   
   return 0;
