@@ -46,12 +46,12 @@
 #define THREE_PI_ON_FOUR 2.35619449019234492884698253745962716
 #define TWO_ON_PI        0.63661977236758134307553505349005744
 
-static double dzero = 0.0;
+static const double dzero = 0.0;
 
 /* jzero for x in [0,8]
  * Index 5849, 19.22 digits precision
  */
-static double pjzero[9] = 
+static const double pjzero[9] = 
 {
   0.4933787251794133561816813446e+21,
   -0.11791576291076105360384408e+21,
@@ -64,7 +64,7 @@ static double pjzero[9] =
   0.2685786856980014981415848441e+5
 };
 
-static double qjzero[9] = 
+static const double qjzero[9] = 
 {
   0.4933787251794133562113278438e+21,
   0.5428918384092285160200195092e+19,
@@ -80,7 +80,7 @@ static double qjzero[9] =
 /* pzero for x in [8,inf]
  * Index 6548, 18.16 digits precision
  */
-static double ppzero[6] = 
+static const double ppzero[6] = 
 {
   0.2277909019730468430227002627e+5,
   0.4134538663958076579678016384e+5,
@@ -90,7 +90,7 @@ static double ppzero[6] =
   0.889615484242104552360748e+0
 };
 
-static double qpzero[6] = 
+static const double qpzero[6] = 
 {
   0.2277909019730468431768423768e+5,
   0.4137041249551041663989198384e+5,
@@ -103,7 +103,7 @@ static double qpzero[6] =
 /* qzero for x in [8,inf]
  * Index 6948, 18.33 digits precision
  */
-static double pqzero[6] = 
+static const double pqzero[6] = 
 {
   -0.8922660020080009409846916e+2,
   -0.18591953644342993800252169e+3,
@@ -113,7 +113,7 @@ static double pqzero[6] =
   -0.8803330304868075181663e-2,
 };
 
-static double qqzero[6] = 
+static const double qqzero[6] = 
 {
   0.571050241285120619052476459e+4,
   0.1195113154343461364695265329e+5,
@@ -126,7 +126,7 @@ static double qqzero[6] =
 /* yzero for x in [0,8]
  * Index 6245, 18.78 digits precision
  */
-static double pyzero[9] = 
+static const double pyzero[9] = 
 {
   -0.2750286678629109583701933175e+20,
   0.6587473275719554925999402049e+20,
@@ -139,7 +139,7 @@ static double pyzero[9] =
   -0.4137035497933148554125235152e+5
 };
 
-static double qyzero[9] = 
+static const double qyzero[9] = 
 {
   0.3726458838986165881989980739e+21,
   0.4192417043410839973904769661e+19,
@@ -155,7 +155,7 @@ static double qyzero[9] =
 /* jone for x in [0,8]
  * Index 6050, 20.98 digits precision
  */
-static double pjone[9] = 
+static const double pjone[9] = 
 {
   0.581199354001606143928050809e+21,
   -0.6672106568924916298020941484e+20,
@@ -168,7 +168,7 @@ static double pjone[9] =
   0.270112271089232341485679099e+4
 };
 
-static double qjone[9] = 
+static const double qjone[9] = 
 {
   0.11623987080032122878585294e+22,
   0.1185770712190320999837113348e+20,
@@ -184,7 +184,7 @@ static double qjone[9] =
 /* pone for x in [8,inf]
  * Index 6749, 18.11 digits precision
  */
-static double ppone[6] = 
+static const double ppone[6] = 
 {
   0.352246649133679798341724373e+5,
   0.62758845247161281269005675e+5,
@@ -194,7 +194,7 @@ static double ppone[6] =
   0.12571716929145341558495e+1
 };
 
-static double qpone[6] = 
+static const double qpone[6] = 
 {
   0.352246649133679798068390431e+5,
   0.626943469593560511888833731e+5,
@@ -207,7 +207,7 @@ static double qpone[6] =
 /* qone for x in [8,inf]
  * Index 7149, 18.28 digits precision
  */
-static double pqone[6] = 
+static const double pqone[6] = 
 {
   0.3511751914303552822533318e+3,
   0.7210391804904475039280863e+3,
@@ -217,7 +217,7 @@ static double pqone[6] =
   0.3532840052740123642735e-1
 };
 
-static double qqone[6] = 
+static const double qqone[6] = 
 {
   0.74917374171809127714519505e+4,
   0.154141773392650970499848051e+5,
@@ -230,7 +230,7 @@ static double qqone[6] =
 /* yone for x in [0,8]
  * Index 6444, 18.24 digits precision
  */
-static double pyone[8] = 
+static const double pyone[8] = 
 {
   -0.2923821961532962543101048748e+20,
   0.7748520682186839645088094202e+19,
@@ -242,7 +242,7 @@ static double pyone[8] =
   0.3556924009830526056691325215e+6
 };
 
-static double qyone[9] = 
+static const double qyone[9] = 
 {
   0.1491311511302920350174081355e+21,
   0.1818662841706134986885065935e+19,
